from codetoolkit.delimiter import Delimiter

if __name__ == "__main__":
    print(Delimiter.split_camel("paycheck"))